@@ -49,7 +49,7 @@ from sagemaker.analytics import TrainingJobAnalytics, HyperparameterTuningJobAna
 from sagemaker.local.local_session import LocalSession  # noqa: F401
 
 from sagemaker.model import Model, ModelPackage  # noqa: F401
-from sagemaker.model_metrics import ModelMetrics, MetricsSource  # noqa: F401
+from sagemaker.model_metrics import ModelMetrics, MetricsSource, FileSource  # noqa: F401
 from sagemaker.pipeline import PipelineModel  # noqa: F401
 from sagemaker.predictor import Predictor  # noqa: F401
 from sagemaker.processing import Processor, ScriptProcessor  # noqa: F401
