@@ -628,9 +628,9 @@ class Model(ModelBase):
             "Framework": framework.upper(),
         }
 
+        multiple_version_supported_framework_list = ["pytorch", "tensorflow"]
         if (
-            framework.lower() == "pytorch"
-            or framework.lower() == "tensorflow"
+            framework.lower() in multiple_version_supported_framework_list
             and target_instance_type is not None
             and re.match("(?=^ml_)(?!ml_inf)", target_instance_type) is not None
             and framework_version is not None
