@@ -14,7 +14,8 @@
 from __future__ import absolute_import
 
 import json
-from sagemaker.workflow.parameters import Parameter as PipelineParameter
+
+from sagemaker.workflow.entities import PipelineVariable
 
 
 class ParameterRange(object):
@@ -71,11 +72,11 @@ class ParameterRange(object):
         return {
             "Name": name,
             "MinValue": str(self.min_value)
-            if not isinstance(self.min_value, PipelineParameter)
-            else self.min_value,
+            if not isinstance(self.min_value, PipelineVariable)
+            else self.min_value.to_string(),
             "MaxValue": str(self.max_value)
-            if not isinstance(self.max_value, PipelineParameter)
-            else self.max_value,
+            if not isinstance(self.max_value, PipelineVariable)
+            else self.max_value.to_string(),
             "ScalingType": self.scaling_type,
         }
 
@@ -108,10 +109,10 @@ class CategoricalParameter(ParameterRange):
             values (list or object): The possible values for the hyperparameter.
                 This input will be converted into a list of strings.
         """
-        if isinstance(values, list):
-            self.values = [str(v) if not isinstance(v, PipelineParameter) else v for v in values]
-        else:
-            self.values = [str(values) if not isinstance(values, PipelineParameter) else values]
+        values = values if isinstance(values, list) else [values]
+        self.values = [
+            str(v) if not isinstance(v, PipelineVariable) else v.to_string() for v in values
+        ]
 
     def as_tuning_range(self, name):
         """Represent the parameter range as a dictionary.
