@@ -10,7 +10,7 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Placeholder docstring"""
+"""Classes for using Scikit-Learn with Amazon SageMaker."""
 from __future__ import absolute_import
 
 from sagemaker.sklearn.estimator import SKLearn  # noqa: F401
